@@ -27,7 +27,8 @@ from uncertainties.backport import *
 def test_numpy():
     
     """
-    Interaction with NumPy, including matrix inversion and correlated_values.
+    Interaction with NumPy, including matrix inversion,
+    correlated_values, and calculation of the mean.
     """
 
     arr = numpy.arange(3)
@@ -68,6 +69,14 @@ def test_numpy():
     else:
         raise Exception("numpy.exp unexpectedly worked")
 
+    # Calculation of the mean, global and with a specific axis:
+
+    arr_floats = numpy.random.random((10, 3, 5))
+    arr = unumpy.uarray(arr_floats, arr_floats/100)
+    assert arr.mean(axis=0).shape == (3, 5)
+    assert arr.mean(axis=1).shape == (10, 5)    
+    arr.mean()  # Global mean
+
 def test_matrix():
     "Matrices of numbers with uncertainties"
     # Matrix inversion:
