@@ -37,7 +37,7 @@ def test_fixed_derivatives_math_funcs():
         # is used as the underlying function:
         numerical_derivatives = uncertainties.NumericalDerivatives(
             lambda *args: func(*args))
-        test_uncertainties._compare_derivatives(func, numerical_derivatives)
+        test_uncertainties.compare_derivatives(func, numerical_derivatives)
 
     # Functions that are not in umath.many_scalars_to_scalar_funcs:
 
@@ -48,11 +48,11 @@ def test_fixed_derivatives_math_funcs():
     def int_part_modf(x):
         return umath.modf(x)[1]
     
-    test_uncertainties._compare_derivatives(
+    test_uncertainties.compare_derivatives(
         frac_part_modf,
         uncertainties.NumericalDerivatives(
             lambda x: frac_part_modf(x)))
-    test_uncertainties._compare_derivatives(
+    test_uncertainties.compare_derivatives(
         int_part_modf,
         uncertainties.NumericalDerivatives(
             lambda x: int_part_modf(x)))
@@ -64,11 +64,11 @@ def test_fixed_derivatives_math_funcs():
     def exponent_frexp(x):
         return umath.frexp(x)[1]
     
-    test_uncertainties._compare_derivatives(
+    test_uncertainties.compare_derivatives(
         mantissa_frexp,
         uncertainties.NumericalDerivatives(
             lambda x: mantissa_frexp(x)))
-    test_uncertainties._compare_derivatives(
+    test_uncertainties.compare_derivatives(
         exponent_frexp,
         uncertainties.NumericalDerivatives(
             lambda x: exponent_frexp(x)))
@@ -149,10 +149,12 @@ def test_monte_carlo_comparison():
                                         n_samples)
         y_samples = numpy.random.normal(y.nominal_value, y.std_dev,
                                         n_samples)
-        function_samples = function(x_samples, y_samples)
+
+        # !! astype() is a fix for median() in NumPy 1.8.0:
+        function_samples = function(x_samples, y_samples).astype(float)
 
         cov_mat = numpy.cov([x_samples, y_samples], function_samples)
-        
+
         return (numpy.median(function_samples), cov_mat)
         
     (nominal_value_samples, covariances_samples) = monte_carlo_calc(1000000)
@@ -165,7 +167,7 @@ def test_monte_carlo_comparison():
     # We rely on the fact that covariances_samples very rarely has
     # null elements:
     
-    assert numpy.vectorize(test_uncertainties._numbers_close)(
+    assert numpy.vectorize(test_uncertainties.numbers_close)(
         covariances_this_module,
         covariances_samples,
         0.05).all(), (
@@ -176,7 +178,7 @@ def test_monte_carlo_comparison():
         )
     
     # The nominal values must be close:
-    assert test_uncertainties._numbers_close(
+    assert test_uncertainties.numbers_close(
         nominal_value_this_module,
         nominal_value_samples,
         # The scale of the comparison depends on the standard
@@ -216,17 +218,24 @@ def test_math_module():
         # math.factorial()):
         assert umath.factorial(4) == 24
 
-        # Boolean functions:
-        assert not umath.isinf(x)
-
-        # Comparison, possibly between an AffineScalarFunc object and a
-        # boolean, which makes things more difficult for this code:
-        assert umath.isinf(x) == False
-
         # fsum is special because it does not take a fixed number of
         # variables:
         assert umath.fsum([x, x]).nominal_value == -3
 
+    # Functions that give locally constant results are tested: they
+    # should give the same result as their float equivalent:
+    for name in umath.locally_cst_funcs:
+
+        try:
+            func = getattr(umath, name)
+        except AttributeError:
+            continue  # Not in the math module, so not in umath either
+        
+        assert func(x) == func(x.nominal_value)
+        # The type should be left untouched. For example, isnan()
+        # should always give a boolean:
+        assert type(func(x)) == type(func(x.nominal_value))
+
     # The same exceptions should be generated when numbers with uncertainties
     # are used:
 
@@ -333,17 +342,17 @@ def test_power_special_cases():
     try:
         umath.pow(ufloat(0, 0.1), negative)
     except (ValueError, OverflowError), err:  # Python 2.6+ "as err"
-        err_type = type(err)  # For Python 3: err is destroyed after except
+        err_class = err.__class__  # For Python 3: err is destroyed after except
     else:
-        err_type = None
+        err_class = None
         
     err_msg = 'A proper exception should have been raised'
 
     # An exception must have occurred:
     if sys.version_info >= (2, 6):
-        assert err_type == ValueError, err_msg
+        assert err_class == ValueError, err_msg
     else:
-        assert err_type == OverflowError, err_msg
+        assert err_class == OverflowError, err_msg
             
     try:
         result = umath.pow(negative, positive)
