@@ -3,7 +3,7 @@ Tests for uncertainties.unumpy.ulinalg.
 
 These tests can be run through the Nose testing framework.
 
-(c) 2010 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>.
+(c) 2010-2013 by Eric O. LEBIGOT (EOL) <eric.lebigot@normalesup.org>.
 """
 
 # Some tests are already performed in test_unumpy (unumpy contains a
@@ -11,10 +11,14 @@ These tests can be run through the Nose testing framework.
 
 from __future__ import division
 
-import numpy
+try:
+    import numpy
+except ImportError:
+    import sys
+    sys.exit()  # There is no reason to test the interface to NumPy
 
 from uncertainties import unumpy, ufloat
-from uncertainties.unumpy.test_unumpy import matrices_close
+from uncertainties.unumpy.test_unumpy import arrays_close
 
 from uncertainties import __author__
 
@@ -47,37 +51,37 @@ def test_list_inverse():
     assert isinstance(mat_list_inv[1,1], float)    
     assert mat_list_inv[1,1] == -1
 
-    x = ufloat((1, 0.1))
-    y = ufloat((2, 0.1))
+    x = ufloat(1, 0.1)
+    y = ufloat(2, 0.1)
     mat = unumpy.matrix([[x, x], [y, 0]])
     
     # Internal consistency: ulinalg.inv() must coincide with the
     # unumpy.matrix inverse, for square matrices (.I is the
     # pseudo-inverse, for non-square matrices, but inv() is not).
-    assert matrices_close(unumpy.ulinalg.inv(mat), mat.I)
+    assert arrays_close(unumpy.ulinalg.inv(mat), mat.I)
 
 
 def test_list_pseudo_inverse():
     "Test of the pseudo-inverse"
 
-    x = ufloat((1, 0.1))
-    y = ufloat((2, 0.1))
+    x = ufloat(1, 0.1)
+    y = ufloat(2, 0.1)
     mat = unumpy.matrix([[x, x], [y, 0]])
 
     # Internal consistency: the inverse and the pseudo-inverse yield
     # the same result on square matrices:
-    assert matrices_close(mat.I, unumpy.ulinalg.pinv(mat), 1e-4)
-    assert matrices_close(unumpy.ulinalg.inv(mat),
+    assert arrays_close(mat.I, unumpy.ulinalg.pinv(mat), 1e-4)
+    assert arrays_close(unumpy.ulinalg.inv(mat),
                           # Support for the optional pinv argument is
                           # tested:
                           unumpy.ulinalg.pinv(mat, 1e-15), 1e-4)
     
     # Non-square matrices:
-    x = ufloat((1, 0.1))
-    y = ufloat((2, 0.1))
+    x = ufloat(1, 0.1)
+    y = ufloat(2, 0.1)
     mat1 = unumpy.matrix([[x, y]])  # "Long" matrix
     mat2 = unumpy.matrix([[x, y], [1, 3+x], [y, 2*x]])  # "Tall" matrix
 
     # Internal consistency:
-    assert matrices_close(mat1.I, unumpy.ulinalg.pinv(mat1, 1e-10))
-    assert matrices_close(mat2.I, unumpy.ulinalg.pinv(mat2, 1e-8))
+    assert arrays_close(mat1.I, unumpy.ulinalg.pinv(mat1, 1e-10))
+    assert arrays_close(mat2.I, unumpy.ulinalg.pinv(mat2, 1e-8))
